# DDK_SDK
拼多多-多多客联盟 CPS 工具包



- 官网
    - https://open.pinduoduo.com/#/index
    - 开发者文档
        - 多多客入驻指南
            - https://open.pinduoduo.com/#/document
        - 多多客API
            - https://open.pinduoduo.com/#/apidocument
        - 多多客权限包
            - http://open.pinduoduo.com/#/apidocument?port=5&id=2
    - 多多进宝
        - https://jinbao.pinduoduo.com/index

- 开发环境
    - python 3.6
    - 仿照 Taobao_topsdk
    - 安装
        - https://pypi.org/project/ddk/
        - pip install ddk
        - pip install ddk --upgrade
        - 卸载
            - pip uninstall ddk